==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CancelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelEventArgsDescription } from "./CancelEventArgsDescription";
/**
 * @hidden
 */
export let CancelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancelEventArgsDescriptionMetadata.a == null) {
                CancelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancelEventArgsDescriptionMetadata.c(CancelEventArgsDescriptionMetadata.a);
            }
            if (a.j(CancelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CancelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            CancelEventArgsDescriptionMetadata.b(a);
            a.aa("CancelEventArgs", () => new CancelEventArgsDescription());
            a.z("CancelEventArgs", CancelEventArgsDescriptionMetadata.a);
        }
    }
    CancelEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancelEventArgsDescriptionMetadata, 'CancelEventArgsDescriptionMetadata');
    CancelEventArgsDescriptionMetadata.a = null;
    return CancelEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CancelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelEventArgsDescription } from "./CancelEventArgsDescription";
/**
 * @hidden
 */
export let CancelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancelEventArgsDescriptionMetadata.a == null) {
                CancelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancelEventArgsDescriptionMetadata.c(CancelEventArgsDescriptionMetadata.a);
            }
            if (a.k(CancelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CancelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            CancelEventArgsDescriptionMetadata.b(a);
            a.ac("CancelEventArgs", () => new CancelEventArgsDescription());
            a.ab("CancelEventArgs", CancelEventArgsDescriptionMetadata.a);
        }
    }
    CancelEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancelEventArgsDescriptionMetadata, 'CancelEventArgsDescriptionMetadata');
    CancelEventArgsDescriptionMetadata.a = null;
    return CancelEventArgsDescriptionMetadata;
})();
